from sqlalchemy import Column, Float, ForeignKey, Integer, String, Text
from sqlalchemy.orm import relationship

from app.models.base import Base


class Item(Base):
    """
    Inventory item model.
    """
    id = Column(Integer, primary_key=True, index=True)
    name = Column(String, index=True, nullable=False)
    sku = Column(String, index=True, unique=True, nullable=False)
    description = Column(Text, nullable=True)
    price = Column(Float, nullable=False)
    quantity = Column(Integer, default=0, nullable=False)
    reorder_level = Column(Integer, default=10, nullable=False)
    
    # Foreign key to Category
    category_id = Column(Integer, ForeignKey("category.id"), nullable=True)
    category = relationship("Category", backref="items")
    
    # Foreign key to User (who created the item)
    owner_id = Column(Integer, ForeignKey("user.id"), nullable=True)
    owner = relationship("User", backref="items")